==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/mk.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управување lightbox Gallary параметри");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Управување Галерија");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Целосна големина на сликата ширина");
define('MANAGE_GALLERY_FULL_HEIGHT', "Поголема слика Висина");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Ширина на сликата");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Висина на слика");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Зачувај палецот Сооднос на сликата");
define('MANAGE_GALLERY_SHOW_TITLES', "Прикажи Наслови");
define('MANAGE_GALLERY_DISABLE_SORT', "Оневозможи Сортирај");
define('MANAGE_GALLERY_DELETE_IMAGE', "Избриши слика");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Зачувај подредување");
define('MANAGE_GALLERY_PUBLISH_MSG', "Кликнете на &quot;Ажурирај&quot; да се објават <br /> вашите поставени слики.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Сите слики се менува големината и поставки се зачувани.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Имаше грешка при промена на големината на сликите или зачувување на поставките.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Сликата (ите) е поставена.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Имаше грешка при поставувањето на сликата (а).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Датотеката што се обидувате да испратите не е слика.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Датотеката што сакате да ја прикачите е премногу голем.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Насловот е зачувана.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Дали сте сигурни дека сакате да ја избришете сликата");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Сликата е избришан.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Имаше грешка при бришење на сликата.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Заштеда на параметри и промена на големината на сликите, почекајте ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Неуспешно, почекајте ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "цел на вид не е зачувана. Дали сакате да ја зачувате редослед?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "цел сликата вид е зачувана.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Имаше заштеда вид на сликата грешка.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/mk.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управување lightbox Gallary параметри");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Управување Галерија");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Целосна големина на сликата ширина");
define('MANAGE_GALLERY_FULL_HEIGHT', "Поголема слика Висина");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Ширина на сликата");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Висина на слика");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Зачувај палецот Сооднос на сликата");
define('MANAGE_GALLERY_SHOW_TITLES', "Прикажи Наслови");
define('MANAGE_GALLERY_DISABLE_SORT', "Оневозможи Сортирај");
define('MANAGE_GALLERY_DELETE_IMAGE', "Избриши слика");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Зачувај подредување");
define('MANAGE_GALLERY_PUBLISH_MSG', "Кликнете на &quot;Ажурирај&quot; да се објават <br /> вашите поставени слики.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Сите слики се менува големината и поставки се зачувани.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Имаше грешка при промена на големината на сликите или зачувување на поставките.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Сликата (ите) е поставена.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Имаше грешка при поставувањето на сликата (а).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Датотеката што се обидувате да испратите не е слика.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Датотеката што сакате да ја прикачите е премногу голем.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Насловот е зачувана.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Дали сте сигурни дека сакате да ја избришете сликата");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Сликата е избришан.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Имаше грешка при бришење на сликата.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Заштеда на параметри и промена на големината на сликите, почекајте ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Неуспешно, почекајте ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "цел на вид не е зачувана. Дали сакате да ја зачувате редослед?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "цел сликата вид е зачувана.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Имаше заштеда вид на сликата грешка.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Датотеката што се обидувате да ја поставите е поголема од поставките за &#39;upload_max_filesize&#39; или &#39;post_max_size&#39; PHP. Контактирајте го администраторот на системот за да ги зголемите овие ограничувања.");
?>
